==> xlniuxdata-vipgame-1.0.31-20151022.063723-16-sources.jar: com/xunlei/niux/data/vipgame/dao/gift/GiftRecordDaoImpl.java <==
package com.xunlei.niux.data.vipgame.dao.gift;

import com.ferret.common.dao.BaseDaoImpl;
import com.xunlei.common.util.StringTools;
import com.xunlei.niux.data.vipgame.dto.ActivityNGiftNGiftRecordDTO;
import com.xunlei.niux.data.vipgame.dto.GiftRecordDTO;
import com.xunlei.niux.data.vipgame.dto.ProductDTO;
import org.apache.commons.lang.StringUtils;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.RowCallbackHandler;
import org.springframework.jdbc.core.namedparam.MapSqlParameterSource;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Set;

/**
 * Created by jamesjxin on 14-4-17.
 */
public class GiftRecordDaoImpl extends BaseDaoImpl implements GiftRecordDao {

    @Override
    public List<GiftRecordDTO> getUnReleaseProductGiftRecord() {
        final List<GiftRecordDTO> giftRecordDTOList = new ArrayList<GiftRecordDTO>();

        String sql = "SELECT giftrecord.*,giftshopreleaserecord.*,gift.goodId FROM giftrecord\n" +
                "LEFT JOIN giftshopreleaserecord ON giftrecord.recordId = giftshopreleaserecord.giftRecordId\n" +
                "LEFT JOIN gift ON giftrecord.giftId = gift.giftId\n" +
                "WHERE giftType = 'product' AND (giftshopreleaserecord.releaseStatus IS NULL OR giftshopreleaserecord.releaseStatus != 1)\n" +
                "and gift.goodId is not null and gift.goodId > 0";


        getJdbcTemplate().query(sql, new RowCallbackHandler() {
            @Override
            public void processRow(final ResultSet resultSet) throws SQLException {
                GiftRecordDTO giftRecordDTO = new GiftRecordDTO();
                giftRecordDTO.setRecordId(resultSet.getLong("recordId"));
                giftRecordDTO.setGiftId(resultSet.getLong("giftId"));
                giftRecordDTO.setUserId(resultSet.getString("userId"));
                giftRecordDTO.setGameId(resultSet.getString("gameId"));
                giftRecordDTO.setServerId(resultSet.getString("serverId"));
                giftRecordDTO.setRoleId(resultSet.getString("roleId"));
                giftRecordDTO.setGiftNum(resultSet.getDouble("giftNum"));
                giftRecordDTO.setMobile(resultSet.getString("mobile"));
                giftRecordDTO.setGiftStatus(resultSet.getString("giftStatus"));
                giftRecordDTO.setActNo(resultSet.getString("actNo"));
                giftRecordDTO.setThirdRecordId(resultSet.getString("thirdRecordId"));
                giftRecordDTO.setFailCause(resultSet.getString("failCause"));
                giftRecordDTO.setRecordTime(resultSet.getString("recordTime"));
                giftRecordDTO.setDealTime(resultSet.getString("dealTime"));
                giftRecordDTO.setExpireDate(resultSet.getString("expireDate"));
                giftRecordDTO.setXunleiVipType(resultSet.getString("xunleiVipType"));
                giftRecordDTO.setParentRecordId(resultSet.getLong("parentRecordId"));
                giftRecordDTO.setIsShow(resultSet.getBoolean("isShow"));
                giftRecordDTO.setSerialNumber(resultSet.getString("serialNumber"));
                giftRecordDTO.setShowLocNo(resultSet.getString("showLocNo"));
                giftRecordDTO.setReleaseStatus(resultSet.getBoolean("releaseStatus"));
                giftRecordDTO.setReleaseTime(resultSet.getString("releaseTime"));
                giftRecordDTO.setGoodId(resultSet.getInt("goodId"));

                giftRecordDTOList.add(giftRecordDTO);
            }
        });

        return giftRecordDTOList;
    }

    @Override
    public List<ProductDTO> getBonusProductChargeList(final int max) {
        final List<ProductDTO> giftRecordDTOList = new ArrayList<ProductDTO>();

        String sql = "SELECT * FROM bonusproductcharge s1 LEFT JOIN gift s2 ON  s1.productId=s2.giftId where s1.isValid=1 order by s1.orderNum desc";

        Object[] args = null;
        if (max > 0) {
            sql += " limit ?";
            args = new Object[]{max};
        }

        getJdbcTemplate().query(sql, args, new RowCallbackHandler() {
            @Override
            public void processRow(final ResultSet resultSet) throws SQLException {
                ProductDTO giftRecordDTO = new ProductDTO();
                giftRecordDTO.setGiftid(resultSet.getString("productId"));
                giftRecordDTO.setGiftName(resultSet.getString("giftName"));
                giftRecordDTO.setTotalNum(resultSet.getLong("totalCount"));
                giftRecordDTO.setRemainNum(resultSet.getLong("leftCount"));
                giftRecordDTO.setGiftBonusNum(resultSet.getLong("bonus"));
                giftRecordDTO.setGiftImgUrl(resultSet.getString("giftPic"));
                giftRecordDTO.setSmallImgUrl(resultSet.getString("smallPicUrl"));
                giftRecordDTO.setFirstLetter(resultSet.getString("firstLetter"));
                giftRecordDTO.setIsTimeLimit(resultSet.getInt("isTimeLimit"));

                //giftType:1实物；2礼包；3其他
                String giftType = resultSet.getString("giftType");
                int giftTypeNum;
                if(StringTools.isEmpty(giftType)){
                    giftTypeNum = 3;
                }else{
                    if("product".equals(giftType)){
                        giftTypeNum = 1;
                    }else if("niuxgift".equals(giftType)){
                        giftTypeNum = 2;
                    }else{
                        giftTypeNum = 3;
                    }
                }
                giftRecordDTO.setGiftType(giftTypeNum);

                String startTime = resultSet.getString("startTime");
                String valdateTime = resultSet.getString("valdateTime");

                giftRecordDTO.setStartTime(StringUtils.isEmpty(startTime) ? "" : format(startTime));
                giftRecordDTO.setValdateTime(StringUtils.isEmpty(valdateTime) ? "" : format(valdateTime));

                giftRecordDTOList.add(giftRecordDTO);
            }
        });

        return giftRecordDTOList;
    }

    @Override
    public List<ProductDTO> getBonusProductChargeList(final int listNum, final boolean isTimeLimit, final boolean isEntityGift) {
        final List<ProductDTO> giftRecordDTOList = new ArrayList<ProductDTO>();

        String sql = "SELECT * FROM bonusproductcharge s1 LEFT JOIN gift s2 ON  s1.productId=s2.giftId where s1.isValid=1 ";

        Object[] args = null;
        if (isTimeLimit) {
            sql += " and isTimeLimit=1";
        }

        if(isEntityGift){
            sql += " and giftType='product'";

        }

        sql += " order by s1.orderNum desc";

        if(listNum > 0){
            sql += " limit 0, " + listNum;
        }

        getJdbcTemplate().query(sql, args, new RowCallbackHandler() {
            @Override
            public void processRow(final ResultSet resultSet) throws SQLException {
                ProductDTO giftRecordDTO = new ProductDTO();
                giftRecordDTO.setGiftid(resultSet.getString("productId"));
                giftRecordDTO.setGiftName(resultSet.getString("giftName"));
                String giftType = resultSet.getString("giftType");
                giftRecordDTO.setGiftType(StringTools.isEmpty(giftType) ? 2 : ("product".equals(giftType) ? 1 : 2));//实物或虚拟
                giftRecordDTO.setTotalNum(resultSet.getLong("totalCount"));
                giftRecordDTO.setRemainNum(resultSet.getLong("leftCount"));
                giftRecordDTO.setGiftBonusNum(resultSet.getLong("bonus"));
                giftRecordDTO.setGiftImgUrl(resultSet.getString("giftPic"));
                giftRecordDTO.setSmallImgUrl(resultSet.getString("smallPicUrl"));
                giftRecordDTO.setFirstLetter(resultSet.getString("firstLetter"));
                giftRecordDTO.setIsTimeLimit(resultSet.getInt("isTimeLimit"));

                String startTime = resultSet.getString("startTime");
                String valdateTime = resultSet.getString("valdateTime");

                giftRecordDTO.setStartTime(StringUtils.isEmpty(startTime) ? "" : format(startTime));
                giftRecordDTO.setValdateTime(StringUtils.isEmpty(valdateTime) ? "" : format(valdateTime));

                giftRecordDTOList.add(giftRecordDTO);
            }
        });

        return giftRecordDTOList;
    }

    @Override
    public List<ProductDTO> getTimeLimitBonusProductChargeList(final int max) {
        final List<ProductDTO> giftRecordDTOList = new ArrayList<ProductDTO>();

        String sql = "SELECT * FROM bonusproductcharge s1 LEFT JOIN gift s2 ON  s1.productId=s2.giftId where s1.isValid=1 and s1.isTimeLimit=1 order by s1.orderNum desc";

        Object[] args = null;
        if (max > 0) {
            sql += " limit ?";
            args = new Object[]{max};
        }

        getJdbcTemplate().query(sql, args, new RowCallbackHandler() {
            @Override
            public void processRow(final ResultSet resultSet) throws SQLException {
                ProductDTO giftRecordDTO = new ProductDTO();
                giftRecordDTO.setGiftid(resultSet.getString("productId"));
                giftRecordDTO.setGiftName(resultSet.getString("giftName"));
                String giftType = resultSet.getString("giftType");
                giftRecordDTO.setGiftType(StringTools.isEmpty(giftType) ? 2 : ("product".equals(giftType) ? 1 : 2));//实物或虚拟
                giftRecordDTO.setTotalNum(resultSet.getLong("totalCount"));
                giftRecordDTO.setRemainNum(resultSet.getLong("leftCount"));
                giftRecordDTO.setGiftBonusNum(resultSet.getLong("bonus"));
                giftRecordDTO.setGiftImgUrl(resultSet.getString("giftPic"));
                giftRecordDTO.setSmallImgUrl(resultSet.getString("smallPicUrl"));
                giftRecordDTO.setValdateTime(resultSet.getString("valdateTime"));
                giftRecordDTO.setFirstLetter(resultSet.getString("firstLetter"));
                giftRecordDTO.setStartTime(resultSet.getString("startTime"));
                giftRecordDTO.setIsTimeLimit(resultSet.getInt("isTimeLimit"));
                giftRecordDTOList.add(giftRecordDTO);
            }
        });

        return giftRecordDTOList;
    }

	@Override
	public List<?> getJiFenShopGiftRecord(final Class<?> object, final String userId,Set<String> giftTypeParamSet, final int pageNo, final int pageSize) {
		List<?> list = new ArrayList<Object>();

        String sql = "SELECT giftrecord.*, giftshopreleaserecord.*, 0 AS goodId FROM giftrecord " +
		" LEFT JOIN giftshopreleaserecord ON giftrecord.recordId = giftshopreleaserecord.giftRecordId " +
        " LEFT JOIN gift ON giftrecord.giftId = gift.giftId " +
		" WHERE giftrecord.userid=:userid AND gift.giftType in (:giftTypeParamSet) AND giftrecord.isshow='1'  "+
		" AND EXISTS (SELECT 1 FROM activity_category WHERE giftrecord.actNo = activity_category.actNo AND activity_category.is_bonusshop = 1) " +
		" ORDER BY giftrecord.recordTime DESC LIMIT :pageNo,:pageSize";

        MapSqlParameterSource parameters = new MapSqlParameterSource();
        parameters.addValue("userid", userId);
        parameters.addValue("giftTypeParamSet", giftTypeParamSet);
        parameters.addValue("pageNo", pageNo);
        parameters.addValue("pageSize", pageSize);
        NamedParameterJdbcTemplate namedParameterJdbcTemplate = new NamedParameterJdbcTemplate(getDataSource());
        return namedParameterJdbcTemplate.query(sql, parameters, new BeanPropertyRowMapper(object));
	}

    @Override
    public List<?> getUserGiftRecordByGiftType(Class<?> object, String userId,  Set<String> giftTypeParamSet, int pageNo, int pageSize) {

        String sql = "SELECT activity.*, gift.* , giftrecord.*, giftshopreleaserecord.*, 0 AS goodId FROM giftrecord " +
                " LEFT JOIN giftshopreleaserecord ON giftrecord.recordId = giftshopreleaserecord.giftRecordId " +
                "LEFT JOIN gift ON giftrecord.giftId = gift.giftId " +
                "LEFT JOIN activity ON giftrecord.actno = activity.actno" +
                " WHERE giftrecord.userid=:userid AND gift.giftType in (:giftTypeParamSet) AND giftrecord.isshow='1' "+
                " ORDER BY giftrecord.recordTime DESC LIMIT :pageNo,:pageSize";
        MapSqlParameterSource parameters = new MapSqlParameterSource();
        parameters.addValue("userid", userId);
        parameters.addValue("giftTypeParamSet", giftTypeParamSet);
        parameters.addValue("pageNo", pageNo);
        parameters.addValue("pageSize", pageSize);
        NamedParameterJdbcTemplate namedParameterJdbcTemplate = new NamedParameterJdbcTemplate(getDataSource());
        return namedParameterJdbcTemplate.query(sql, parameters, new BeanPropertyRowMapper(object));

    }

    @Override
    public int countUserGiftRecordByGiftType(String userId, Set<String> giftTypeParamSet) {
        String sql = "SELECT count(*) FROM giftrecord " +
                " LEFT JOIN gift ON giftrecord.giftId = gift.giftId " +
                " WHERE giftrecord.userid=:userid AND gift.giftType in (:giftTypeParamSet) AND giftrecord.isshow='1' ";

        MapSqlParameterSource parameters = new MapSqlParameterSource();
        parameters.addValue("userid", userId);
        parameters.addValue("giftTypeParamSet", giftTypeParamSet);
        NamedParameterJdbcTemplate namedParameterJdbcTemplate = new NamedParameterJdbcTemplate(getDataSource());
        return namedParameterJdbcTemplate.queryForInt(sql, parameters);
    }

    @Override
    public int countJiFenShopGiftRecord( String userId, Set<String> giftTypeParamSet) {
        String sql = "SELECT count(*) FROM giftrecord " +
                " LEFT JOIN gift ON giftrecord.giftId = gift.giftId " +
                " WHERE giftrecord.userid=:userid AND gift.giftType in (:giftTypeParamSet) AND giftrecord.isshow='1' "+
                " AND EXISTS (SELECT 1 FROM activity_category WHERE giftrecord.actNo = activity_category.actNo AND activity_category.is_bonusshop = 1) ";

        MapSqlParameterSource parameters = new MapSqlParameterSource();
        parameters.addValue("userid", userId);
        parameters.addValue("giftTypeParamSet", giftTypeParamSet);
        NamedParameterJdbcTemplate namedParameterJdbcTemplate = new NamedParameterJdbcTemplate(getDataSource());
        return namedParameterJdbcTemplate.queryForInt(sql, parameters);
    }


    @Override
    public List<ActivityNGiftNGiftRecordDTO> getUserGiftRecordsByActNo(String userId, String actNo) {
        String sql = "select giftrecord.*,gift.* from \n" +
                "gift join giftrecord on gift.giftId = giftrecord.giftId\n" +
                "where giftrecord.isshow='1' and giftrecord.actNo=:actNo and giftrecord.userId=:userId";
        MapSqlParameterSource parameters = new MapSqlParameterSource();
        parameters.addValue("userId", userId);
        parameters.addValue("actNo", actNo);
        NamedParameterJdbcTemplate namedParameterJdbcTemplate = new NamedParameterJdbcTemplate(getDataSource());
        return namedParameterJdbcTemplate.query(sql, parameters, new BeanPropertyRowMapper(ActivityNGiftNGiftRecordDTO.class));
    }

	@Override
	public int countGiftRecordInOneDay(String userId, String date) {
		String sql = "select count(*) from bonusproductchargerecord where STR_TO_DATE(recordTime, '%Y-%m-%d')=:recordTime and userId=:userId and chargeFlag<>4";
        MapSqlParameterSource parameters = new MapSqlParameterSource();
        parameters.addValue("recordTime", date);
        parameters.addValue("userId", userId);
        NamedParameterJdbcTemplate namedParameterJdbcTemplate = new NamedParameterJdbcTemplate(getDataSource());
        
        int a =  namedParameterJdbcTemplate.queryForInt(sql, parameters);
        return a ;
	}

    private String format(String time){
        try{
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date date = sdf.parse(time);

            SimpleDateFormat sdf1 = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");
            String resultStr = sdf1.format(date);

            return resultStr;
        }catch(Exception e){
            return "";
        }
    }

}

==> xlniuxdata-vipgame-1.0.32-20151028.071625-7-sources.jar: com/xunlei/niux/data/vipgame/dao/gift/GiftRecordDaoImpl.java <==
package com.xunlei.niux.data.vipgame.dao.gift;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Set;

import com.xunlei.niux.data.vipgame.dto.ActivityNGiftNGiftRecordDTO;
import com.xunlei.niux.data.vipgame.dto.RebateOrderGroupByApOrderIdDTO;
import org.apache.commons.lang.StringUtils;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.RowCallbackHandler;

import com.ferret.common.dao.BaseDaoImpl;
import com.xunlei.common.util.StringTools;
import com.xunlei.niux.data.vipgame.dto.GiftRecordDTO;
import com.xunlei.niux.data.vipgame.dto.ProductDTO;
import org.springframework.jdbc.core.namedparam.MapSqlParameterSource;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;

/**
 * Created by jamesjxin on 14-4-17.
 */
public class GiftRecordDaoImpl extends BaseDaoImpl implements GiftRecordDao {

    @Override
    public List<GiftRecordDTO> getUnReleaseProductGiftRecord() {
        final List<GiftRecordDTO> giftRecordDTOList = new ArrayList<GiftRecordDTO>();

        String sql = "SELECT giftrecord.*,giftshopreleaserecord.*,gift.goodId FROM giftrecord\n" +
                "LEFT JOIN giftshopreleaserecord ON giftrecord.recordId = giftshopreleaserecord.giftRecordId\n" +
                "LEFT JOIN gift ON giftrecord.giftId = gift.giftId\n" +
                "WHERE giftType = 'product' AND (giftshopreleaserecord.releaseStatus IS NULL OR giftshopreleaserecord.releaseStatus != 1)\n" +
                "and gift.goodId is not null and gift.goodId > 0";


        getJdbcTemplate().query(sql, new RowCallbackHandler() {
            @Override
            public void processRow(final ResultSet resultSet) throws SQLException {
                GiftRecordDTO giftRecordDTO = new GiftRecordDTO();
                giftRecordDTO.setRecordId(resultSet.getLong("recordId"));
                giftRecordDTO.setGiftId(resultSet.getLong("giftId"));
                giftRecordDTO.setUserId(resultSet.getString("userId"));
                giftRecordDTO.setGameId(resultSet.getString("gameId"));
                giftRecordDTO.setServerId(resultSet.getString("serverId"));
                giftRecordDTO.setRoleId(resultSet.getString("roleId"));
                giftRecordDTO.setGiftNum(resultSet.getDouble("giftNum"));
                giftRecordDTO.setMobile(resultSet.getString("mobile"));
                giftRecordDTO.setGiftStatus(resultSet.getString("giftStatus"));
                giftRecordDTO.setActNo(resultSet.getString("actNo"));
                giftRecordDTO.setThirdRecordId(resultSet.getString("thirdRecordId"));
                giftRecordDTO.setFailCause(resultSet.getString("failCause"));
                giftRecordDTO.setRecordTime(resultSet.getString("recordTime"));
                giftRecordDTO.setDealTime(resultSet.getString("dealTime"));
                giftRecordDTO.setExpireDate(resultSet.getString("expireDate"));
                giftRecordDTO.setXunleiVipType(resultSet.getString("xunleiVipType"));
                giftRecordDTO.setParentRecordId(resultSet.getLong("parentRecordId"));
                giftRecordDTO.setIsShow(resultSet.getBoolean("isShow"));
                giftRecordDTO.setSerialNumber(resultSet.getString("serialNumber"));
                giftRecordDTO.setShowLocNo(resultSet.getString("showLocNo"));
                giftRecordDTO.setReleaseStatus(resultSet.getBoolean("releaseStatus"));
                giftRecordDTO.setReleaseTime(resultSet.getString("releaseTime"));
                giftRecordDTO.setGoodId(resultSet.getInt("goodId"));

                giftRecordDTOList.add(giftRecordDTO);
            }
        });

        return giftRecordDTOList;
    }

    @Override
    public List<ProductDTO> getBonusProductChargeList(final int max) {
        final List<ProductDTO> giftRecordDTOList = new ArrayList<ProductDTO>();

        String sql = "SELECT * FROM bonusproductcharge s1 LEFT JOIN gift s2 ON  s1.productId=s2.giftId where s1.isValid=1 order by s1.orderNum desc";

        Object[] args = null;
        if (max > 0) {
            sql += " limit ?";
            args = new Object[]{max};
        }

        getJdbcTemplate().query(sql, args, new RowCallbackHandler() {
            @Override
            public void processRow(final ResultSet resultSet) throws SQLException {
                ProductDTO giftRecordDTO = new ProductDTO();
                giftRecordDTO.setGiftid(resultSet.getString("productId"));
                giftRecordDTO.setGiftName(resultSet.getString("giftName"));
                String giftType = resultSet.getString("giftType");
                giftRecordDTO.setGiftType(StringTools.isEmpty(giftType) ? 2 : ("product".equals(giftType) ? 1 : 2));//实物或虚拟
                giftRecordDTO.setTotalNum(resultSet.getLong("totalCount"));
                giftRecordDTO.setRemainNum(resultSet.getLong("leftCount"));
                giftRecordDTO.setGiftBonusNum(resultSet.getLong("bonus"));
                giftRecordDTO.setGiftImgUrl(resultSet.getString("giftPic"));
                giftRecordDTO.setSmallImgUrl(resultSet.getString("smallPicUrl"));
                giftRecordDTO.setFirstLetter(resultSet.getString("firstLetter"));
                giftRecordDTO.setIsTimeLimit(resultSet.getInt("isTimeLimit"));

                String startTime = resultSet.getString("startTime");
                String valdateTime = resultSet.getString("valdateTime");

                giftRecordDTO.setStartTime(StringUtils.isEmpty(startTime) ? "" : format(startTime));
                giftRecordDTO.setValdateTime(StringUtils.isEmpty(valdateTime) ? "" : format(valdateTime));

                giftRecordDTOList.add(giftRecordDTO);
            }
        });

        return giftRecordDTOList;
    }

    @Override
    public List<ProductDTO> getBonusProductChargeList(final int listNum, final boolean isTimeLimit, final boolean isEntityGift) {
        final List<ProductDTO> giftRecordDTOList = new ArrayList<ProductDTO>();

        String sql = "SELECT * FROM bonusproductcharge s1 LEFT JOIN gift s2 ON  s1.productId=s2.giftId where s1.isValid=1 ";

        Object[] args = null;
        if (isTimeLimit) {
            sql += " and isTimeLimit=1";
        }

        if(isEntityGift){
            sql += " and giftType='product'";

        }

        sql += " order by s1.orderNum desc";

        if(listNum > 0){
            sql += " limit 0, " + listNum;
        }

        getJdbcTemplate().query(sql, args, new RowCallbackHandler() {
            @Override
            public void processRow(final ResultSet resultSet) throws SQLException {
                ProductDTO giftRecordDTO = new ProductDTO();
                giftRecordDTO.setGiftid(resultSet.getString("productId"));
                giftRecordDTO.setGiftName(resultSet.getString("giftName"));
                String giftType = resultSet.getString("giftType");
                giftRecordDTO.setGiftType(StringTools.isEmpty(giftType) ? 2 : ("product".equals(giftType) ? 1 : 2));//实物或虚拟
                giftRecordDTO.setTotalNum(resultSet.getLong("totalCount"));
                giftRecordDTO.setRemainNum(resultSet.getLong("leftCount"));
                giftRecordDTO.setGiftBonusNum(resultSet.getLong("bonus"));
                giftRecordDTO.setGiftImgUrl(resultSet.getString("giftPic"));
                giftRecordDTO.setSmallImgUrl(resultSet.getString("smallPicUrl"));
                giftRecordDTO.setFirstLetter(resultSet.getString("firstLetter"));
                giftRecordDTO.setIsTimeLimit(resultSet.getInt("isTimeLimit"));

                String startTime = resultSet.getString("startTime");
                String valdateTime = resultSet.getString("valdateTime");

                giftRecordDTO.setStartTime(StringUtils.isEmpty(startTime) ? "" : format(startTime));
                giftRecordDTO.setValdateTime(StringUtils.isEmpty(valdateTime) ? "" : format(valdateTime));

                giftRecordDTOList.add(giftRecordDTO);
            }
        });

        return giftRecordDTOList;
    }

    @Override
    public List<ProductDTO> getTimeLimitBonusProductChargeList(final int max) {
        final List<ProductDTO> giftRecordDTOList = new ArrayList<ProductDTO>();

        String sql = "SELECT * FROM bonusproductcharge s1 LEFT JOIN gift s2 ON  s1.productId=s2.giftId where s1.isValid=1 and s1.isTimeLimit=1 order by s1.orderNum desc";

        Object[] args = null;
        if (max > 0) {
            sql += " limit ?";
            args = new Object[]{max};
        }

        getJdbcTemplate().query(sql, args, new RowCallbackHandler() {
            @Override
            public void processRow(final ResultSet resultSet) throws SQLException {
                ProductDTO giftRecordDTO = new ProductDTO();
                giftRecordDTO.setGiftid(resultSet.getString("productId"));
                giftRecordDTO.setGiftName(resultSet.getString("giftName"));
                String giftType = resultSet.getString("giftType");
                giftRecordDTO.setGiftType(StringTools.isEmpty(giftType) ? 2 : ("product".equals(giftType) ? 1 : 2));//实物或虚拟
                giftRecordDTO.setTotalNum(resultSet.getLong("totalCount"));
                giftRecordDTO.setRemainNum(resultSet.getLong("leftCount"));
                giftRecordDTO.setGiftBonusNum(resultSet.getLong("bonus"));
                giftRecordDTO.setGiftImgUrl(resultSet.getString("giftPic"));
                giftRecordDTO.setSmallImgUrl(resultSet.getString("smallPicUrl"));
                giftRecordDTO.setValdateTime(resultSet.getString("valdateTime"));
                giftRecordDTO.setFirstLetter(resultSet.getString("firstLetter"));
                giftRecordDTO.setStartTime(resultSet.getString("startTime"));
                giftRecordDTO.setIsTimeLimit(resultSet.getInt("isTimeLimit"));
                giftRecordDTOList.add(giftRecordDTO);
            }
        });

        return giftRecordDTOList;
    }

	@Override
	public List<?> getJiFenShopGiftRecord(final Class<?> object, final String userId,Set<String> giftTypeParamSet, final int pageNo, final int pageSize) {
		List<?> list = new ArrayList<Object>();

        String sql = "SELECT giftrecord.*, giftshopreleaserecord.*, 0 AS goodId FROM giftrecord " +
		" LEFT JOIN giftshopreleaserecord ON giftrecord.recordId = giftshopreleaserecord.giftRecordId " +
        " LEFT JOIN gift ON giftrecord.giftId = gift.giftId " +
		" WHERE giftrecord.userid=:userid AND gift.giftType in (:giftTypeParamSet) AND giftrecord.isshow='1'  "+
		" AND EXISTS (SELECT 1 FROM activity_category WHERE giftrecord.actNo = activity_category.actNo AND activity_category.is_bonusshop = 1) " +
		" ORDER BY giftrecord.recordTime DESC LIMIT :pageNo,:pageSize";

        MapSqlParameterSource parameters = new MapSqlParameterSource();
        parameters.addValue("userid", userId);
        parameters.addValue("giftTypeParamSet", giftTypeParamSet);
        parameters.addValue("pageNo", pageNo);
        parameters.addValue("pageSize", pageSize);
        NamedParameterJdbcTemplate namedParameterJdbcTemplate = new NamedParameterJdbcTemplate(getDataSource());
        return namedParameterJdbcTemplate.query(sql, parameters, new BeanPropertyRowMapper(object));
	}

    @Override
    public List<?> getUserGiftRecordByGiftType(Class<?> object, String userId,  Set<String> giftTypeParamSet, int pageNo, int pageSize) {

        String sql = "SELECT activity.*, gift.* , giftrecord.*, giftshopreleaserecord.*, 0 AS goodId FROM giftrecord " +
                " LEFT JOIN giftshopreleaserecord ON giftrecord.recordId = giftshopreleaserecord.giftRecordId " +
                "LEFT JOIN gift ON giftrecord.giftId = gift.giftId " +
                "LEFT JOIN activity ON giftrecord.actno = activity.actno" +
                " WHERE giftrecord.userid=:userid AND gift.giftType in (:giftTypeParamSet) AND giftrecord.isshow='1' "+
                " ORDER BY giftrecord.recordTime DESC LIMIT :pageNo,:pageSize";
        MapSqlParameterSource parameters = new MapSqlParameterSource();
        parameters.addValue("userid", userId);
        parameters.addValue("giftTypeParamSet", giftTypeParamSet);
        parameters.addValue("pageNo", pageNo);
        parameters.addValue("pageSize", pageSize);
        NamedParameterJdbcTemplate namedParameterJdbcTemplate = new NamedParameterJdbcTemplate(getDataSource());
        return namedParameterJdbcTemplate.query(sql, parameters, new BeanPropertyRowMapper(object));

    }

    @Override
    public int countUserGiftRecordByGiftType(String userId, Set<String> giftTypeParamSet) {
        String sql = "SELECT count(*) FROM giftrecord " +
                " LEFT JOIN gift ON giftrecord.giftId = gift.giftId " +
                " WHERE giftrecord.userid=:userid AND gift.giftType in (:giftTypeParamSet) AND giftrecord.isshow='1' ";

        MapSqlParameterSource parameters = new MapSqlParameterSource();
        parameters.addValue("userid", userId);
        parameters.addValue("giftTypeParamSet", giftTypeParamSet);
        NamedParameterJdbcTemplate namedParameterJdbcTemplate = new NamedParameterJdbcTemplate(getDataSource());
        return namedParameterJdbcTemplate.queryForInt(sql, parameters);
    }

    @Override
    public int countJiFenShopGiftRecord( String userId, Set<String> giftTypeParamSet) {
        String sql = "SELECT count(*) FROM giftrecord " +
                " LEFT JOIN gift ON giftrecord.giftId = gift.giftId " +
                " WHERE giftrecord.userid=:userid AND gift.giftType in (:giftTypeParamSet) AND giftrecord.isshow='1' "+
                " AND EXISTS (SELECT 1 FROM activity_category WHERE giftrecord.actNo = activity_category.actNo AND activity_category.is_bonusshop = 1) ";

        MapSqlParameterSource parameters = new MapSqlParameterSource();
        parameters.addValue("userid", userId);
        parameters.addValue("giftTypeParamSet", giftTypeParamSet);
        NamedParameterJdbcTemplate namedParameterJdbcTemplate = new NamedParameterJdbcTemplate(getDataSource());
        return namedParameterJdbcTemplate.queryForInt(sql, parameters);
    }


    @Override
    public List<ActivityNGiftNGiftRecordDTO> getUserGiftRecordsByActNo(String userId, String actNo) {
        String sql = "select giftrecord.*,gift.* from \n" +
                "gift join giftrecord on gift.giftId = giftrecord.giftId\n" +
                "where giftrecord.isshow='1' and giftrecord.actNo=:actNo and giftrecord.userId=:userId";
        MapSqlParameterSource parameters = new MapSqlParameterSource();
        parameters.addValue("userId", userId);
        parameters.addValue("actNo", actNo);
        NamedParameterJdbcTemplate namedParameterJdbcTemplate = new NamedParameterJdbcTemplate(getDataSource());
        return namedParameterJdbcTemplate.query(sql, parameters, new BeanPropertyRowMapper(ActivityNGiftNGiftRecordDTO.class));
    }

	@Override
	public int countGiftRecordInOneDay(String userId, String date) {
		String sql = "select count(*) from bonusproductchargerecord where STR_TO_DATE(recordTime, '%Y-%m-%d')=:recordTime and userId=:userId and chargeFlag<>4";
        MapSqlParameterSource parameters = new MapSqlParameterSource();
        parameters.addValue("recordTime", date);
        parameters.addValue("userId", userId);
        NamedParameterJdbcTemplate namedParameterJdbcTemplate = new NamedParameterJdbcTemplate(getDataSource());
        
        int a =  namedParameterJdbcTemplate.queryForInt(sql, parameters);
        return a ;
	}

    private String format(String time){
        try{
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date date = sdf.parse(time);

            SimpleDateFormat sdf1 = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");
            String resultStr = sdf1.format(date);

            return resultStr;
        }catch(Exception e){
            return "";
        }
    }

}
